Tin tức thư viện

Chức năng Dừng xem quảng cáo trên violet.vn

12087057 Kính chào các thầy, cô! Hiện tại, kinh phí duy trì hệ thống dựa chủ yếu vào việc đặt quảng cáo trên hệ thống. Tuy nhiên, đôi khi có gây một số trở ngại đối với thầy, cô khi truy cập. Vì vậy, để thuận tiện trong việc sử dụng thư viện hệ thống đã cung cấp chức năng...
Xem tiếp

Hỗ trợ kĩ thuật

  • (024) 62 930 536
  • 091 912 4899
  • hotro@violet.vn

Liên hệ quảng cáo

  • (024) 66 745 632
  • 096 181 2005
  • contact@bachkim.vn

CD5B12 Tin 6 KNTT Trình bày thông tin ở dạng bảng

Wait
  • Begin_button
  • Prev_button
  • Play_button
  • Stop_button
  • Next_button
  • End_button
  • 0 / 0
  • Loading_status
Nhấn vào đây để tải về
Báo tài liệu có sai sót
Nhắn tin cho tác giả
(Tài liệu chưa được thẩm định)
Nguồn:
Người gửi: Võ Nhật Trường (trang riêng)
Ngày gửi: 04h:33' 12-02-2024
Dung lượng: 7.4 MB
Số lượt tải: 180
Số lượt thích: 0 người
KẾ HOẠCH BÀI DẠY
(Kèm theo Công văn số 1677 /SGDĐT-GDTrH ngày 17 tháng 8 năm 2021 của Sở GDĐT tỉnh Bình Định)

Trường:THCS Tam Quan Bắc
Tổ: TIN-GDTC-LỊCH SỬ & ĐỊA LÝ
Ngày soạn: 12.02.2024

Họ và tên giáo viên:
Võ Nhật Trường

Chủ đề 5: ỨNG DỤNG TIN HỌC

Bài 12. TRÌNH BÀY THÔNG TIN Ở DẠNG BẢNG
Môn: Tin học lớp: 6
Thời gian thực hiện: (2 tiết: 24-25)

I. Mục tiêu
1. Về kiến thức:
-Biết được ưu điểm của việc trình bày thông tin dạng bảng.
-Trình bày được thông tin ở dạng bảng bằng phần mềm soạn thảo văn bản.
2. Về năng lực:
2.1. Năng lực chung
-Năng lực tự chủ, tự học: HS biết đọc sách giáo khoa, kết hợp với trải nghiệm thực tế để giải quyết các yêu
cầu cuộc sống.
-Năng lực giao tiếp và hợp tác: Rèn kĩ năng hợp tác, giao tiếp và thuyết trình.
-Năng lực tư duy và sáng tạo: Phát triển tư duy logic, năng lực phân tích, đánh giá, khái quát, giải quyết vấn
đề..
2.2. Năng lực Tin học
-Nội dung trong bài học gắn liền với thực tế giúp các em trong việc tích lũy kiến thức, kĩ năng ứng dụng
công nghệ và vận dụng vào cuộc sống.
-Học sinh hình thành các kĩ năng khai thác và sử dụng phần mềm soạn thảo văn bản phục vụ nhu cầu học
tập và cuộc sống.
3. Về phẩm chất:
-Phát triển tinh thần hợp tác, chia sẻ tài nguyên và trách nhiệm trong làm việc nhóm.
-Khuyến khích sự cởi mở, làm việc với mục tiêu chung và trách nhiệm cá nhân
-Các hoạt động luôn hướng đến sự khuyến khích các em có ý thức trách nhiệm, biết chia sẻ, tăng cường giao
tiếp, tính chính xác, cẩn trọng.
-Hình thành phẩm chất chăm chỉ, tự học, tự giác, trung thực, trách nhiệm.
II. Thiết bị dạy học và học liệu
1. Thiết bị dạy học:
- Phòng máy, Tivi,... phục vụ cho dạy và học lý thuyết và thực hành.
2. Học liệu:
- GV: Hệ thống câu hỏi, bài tập.
- HS: SGK, SBT, bút màu, vở ghi chép. bảng nhóm, phiếu học tập, phiếu khảo sát, … (đáp ứng yêu cầu học
tập). Chuẩn bị bài tập nhóm được phân công.
III. TIẾN TRÌNH DẠY HỌC
A. HOẠT ĐỘNG KHỞI ĐỘNG (KHÁM PHÁ) (Dự kiến thời lượng 5')
a. Mục tiêu:
-Giới thiệu nội dung cần tìm hiểu trong chủ đề/bài học:
+1. Trình bày thông tin ở dạng bảng
+2. Tạo bảng.
+3. Định dạng bảng.
+4. Thực hành: Tạo bảng.
-Giới thiệu khái quát về chủ đề bài học. Hướng dẫn học sinh đọc đoạn văn bản SGK để dẫn nhập vào nội
dung bài học.
b) Nội dung:
-Cho HS quan sát và tìm hiểu đoạn văn bản trong sách giáo khoa (bài giảng điện tử), trả lời câu hỏi phiếu số
1 và dẫn vào nội dung chính cần tìm hiểu của bài học.
c) Sản phẩm: Học sinh đọc nội dung đoạn văn bản.

1

PHIẾU SỐ 1 CD5B12
Họ và tên: ………………………………….. Lớp:….. Nhóm: ……………………
Hình 5.11 cho thấy hai cách trình -Cách trình bày bảng giúp người xem dễ quan sát và bao quát
bày danh sách học sinh trong cuốn những thông tin trong cuốn sổ lưu niệm hơn nhưng sẽ ghi được ít
sổ lưu niệm. Trang bên trái sử dụng thông tin của từng cá nhân hơn.
bảng, trang bên phải liệt kê lần lượt -Cách trình bày theo danh sách liệt kê giúp người xem dễ dàng nắm
danh sách các thành viên. Em hãy bắt thông tin của từng cá nhân, nhưng không bao quát được tất cả.
nhận xét về hai cách trình bày này?
Em sẽ lựa chọn cách nào để trình Mỗi cách trình bày đều có những ưu - nhược điểm của nó
bày danh sách học sinh trong cuốn
sổ lưu niệm của lớp em? Tại sao?
d) Tổ chức thực hiện
-Chiếu đoạn văn bản, hình ảnh yêu cầu học sinh đưa ra nhận xét.
-GV nhận xét kết quả của HS, từ đó GV đưa ra mục tiêu của bài học
B. HOẠT ĐỘNG HÌNH THÀNH KIẾN THỨC (Dự kiến thời lượng 55')
Hoạt động 1: 1. Trình bày thông tin ở dạng bảng (Dự kiến thời lượng 10')
a) Mục tiêu: Học sinh biết thông tin dạng bảng. Ưu điểm của trình bày thông tin dạng bảng.
b) Nội dung: Tìm hiểu về “Trình bày thông tin ở dạng bảng”. Học sinh nghiên cứu SGK hoặc quan sát, theo
dõi bài giảng và hoàn thiện phiếu học tập số 2, 3.
c) Sản phẩm: Phiếu học tập của học sinh.
Sản phẩm dự kiến:
PHIẾU SỐ 2 CD5B12

Bảng trên gồm mấy cột, mấy hàng?
Trò chơi nào được nhiều bạn nam yêu thích nhất?
Trò chơi nào được nhiều bạn nữ yêu thích nhất?

Bảng trên gồm 4 cột , 5 hàng.
Trò chơi kéo co được nhiều bạn nam yêu thích nhất.
Trò chơi lò cò tiếp sức được nhiều bạn nữ yêu thích
nhất.
Trò chơi nào được học sinh của lớp yêu thích Trò chơi kéo co được học sinh của lớp yêu thích
nhất?
nhất.
Nếu không dùng bảng biểu diễn thì việc tìm kiếm Nếu không dùng bảng biểu diễn thì việc tìm kiếm
có dễ không?
khó khăn hơn
PHIẾU SỐ 3 CD5B12
Em hãy nêu tác Tác dụng của việc trình bày thông tin dạng bảng:
dụng của việc -Chúng ta có thể sử dụng bảng để trình bày thông tin một cách cô đọng.
trình bày thông -Bảng thường được sử dụng để ghi lại dữ liệu của công việc thống kê, điều tra, khảo
tin dạng bảng?
sát,...
-Từ bảng dữ liệu, em có thể dễ dàng tìm kiếm, so sánh, tổng hợp được thông tin.
d) Tổ chức thực hiện:
-Bước 1: Chuyển giao nhiệm vụ
+Hoạt động nhóm (chia từ 2hs/nhóm) hoặc cá nhân. Phát phiếu học tập cho học sinh và yêu cầu học sinh
hoàn thiện phiếu học tập, bài tập.
+HS điền thông tin tìm hiểu, nghiên cứu, trả lời các yêu cầu trong phiếu học tập số 2, 3.
+GV: Yêu cầu các nhóm hoàn thành nhiệm vụ học tập.
-Bước 2: Thực hiện nhiệm vụ
+ HS tiếp nhận nhiệm vụ, lắng nghe, nghiên cứu, suy nghĩ và thảo luận, ghi vào vở, phiếu học tập
+ GV quan sát, hướng dẫn HS khi cần.
- Bước 3: Báo cáo, thảo luận

2

+ HS trình bày kết quả
+ HS khác nhận xét, bổ sung đáp án cho bạn.
+ HS cùng GV thảo luận nội dung.
- Bước 4: Kết luận, nhận định, đánh giá
+ GV nhận xét, đánh giá và chuẩn kiến thức
+HS: Nhận kết quả đánh giá của giáo viên và so sánh với phương án mẫu, tự sửa sai nếu có. Rút kinh
nghiệm, bài học.
Kiến thức:
* Tác dụng của việc trình bày thông tin dạng bảng:
-Chúng ta có thể sử dụng bảng để trình bày thông tin một cách cô đọng.
-Bảng thường được sử dụng để ghi lại dữ liệu của công việc thống kê, điều tra, khảo sát,...
-Từ bảng dữ liệu, em có thể dễ dàng tìm kiếm, so sánh, tổng hợp được thông tin.
Hoạt động 2: 2. Tạo bảng: (Dự kiến thời lượng 15')
a) Mục tiêu: - Học sinh biết cách trình bày thông tin dạng bảng, tạo bảng.
b) Nội dung: Tìm hiểu về “Tạo bảng.”. GV yêu cầu học sinh nghiên cứu SGK hoặc quan sát, theo dõi bài
giảng, thảo luận và hoàn thiện phiếu học tập số 4, 5, 6, 7.
c) Sản phẩm: Phiếu học tập của học sinh
Sản phẩm dự kiến:
PHIẾU SỐ 4 CD5B12
Em hãy nêu các Cách thực hiện:
bước để tạo bảng? -B1: Chọn lệnh Table trên dải lệnh Insert.
-B2: Kéo thả chuột để chọn số hàng, số cột cho bảng. Một bảng trống được tạo với số
hàng và số cột như đã chọn.
PHIẾU SỐ 5 CD5B12
Tạo bảng bằng hộp thoại Insert Table:
Em hãy nêu các bước
-B1: Chọn Insert/ Table /Insert Table
để tạo bảng bằng hộp
-B2: Nhập số cột, số hàng của bảng.
thoại Insert Table?
-B3: Chọn lệnh OK (Enter)
PHIẾU SỐ 6 CD5B12
Em hãy nêu cách -Muốn nhập nội dung vào ô nào, ta nháy chuột để đặt con trỏ soạn thảo tại ô đó và
nhập nội dung và di nhập dữ liệu.
chuyển trong bảng? -Sử dụng các phím mũi tên trên bàn phím hoặc chuột để di chuyển con trỏ soạn
thảo.
PHIẾU SỐ 7 CD5B12
Em hãy nêu cách Thay đổi độ rộng cột hay độ cao hàng của bảng:
thay đổi độ rộng -B1. Đưa con trỏ chuột vào đường biên của cột (hay hàng) cần thay đổi cho đến khi
cột, độ cao hàng con trỏ có dạng
hoặc
của bảng?
-B2. Kéo chuột sang trái, phải (hoặc lên, xuống) để thay đổi kích thước của hàng
hoặc cột.
d) Tổ chức thực hiện:
-Bước 1: Chuyển giao nhiệm vụ
+Hoạt động nhóm (chia từ 2hs/nhóm) hoặc cá nhân. Phát phiếu học tập cho học sinh và yêu cầu học sinh
hoàn thiện phiếu học tập, bài tập
+HS điền thông tin tìm hiểu, nghiên cứu, trả lời các yêu cầu trong phiếu học tập số 4, 5, 6, 7.
+GV: Yêu cầu các nhóm hoàn thành nhiệm vụ học tập.
-Bước 2: Thực hiện nhiệm vụ
+ HS tiếp nhận nhiệm vụ, lắng nghe, nghiên cứu, suy nghĩ và thảo luận, ghi vào vở, phiếu học tập
+ GV quan sát, hướng dẫn HS khi cần
- Bước 3: Báo cáo, thảo luận

3

+ HS trình bày kết quả
+ HS khác nhận xét, bổ sung đáp án cho bạn.
+ HS cùng GV thảo luận nội dung.
- Bước 4: Kết luận, nhận định, đánh giá
+ GV nhận xét, đánh giá và chuẩn kiến thức
+HS: Nhận kết quả đánh giá của giáo viên và so sánh với phương án mẫu, tự sửa sai nếu có. Rút kinh
nghiệm, bài học.
Kiến thức:
* Các bước để tạo bảng:
-B1: Chọn lệnh Table trên dải lệnh Insert.
-B2: Kéo thả chuột để chọn số hàng, số cột cho bảng. Một bảng trống được tạo với số hàng và số cột như
đã chọn.
* Tạo bảng bằng hộp thoại Insert Table:
-B1: Chọn Insert/ Table /Insert Table
-B2: Nhập số cột, số hàng của bảng.
-B3: Chọn lệnh OK (Enter)
* Cách nhập nội dung và di chuyển trong bảng
-Muốn nhập nội dung vào ô nào, ta nháy chuột để đặt con trỏ soạn thảo tại ô đó và nhập dữ liệu.
-Sử dụng các phím mũi tên trên bàn phím hoặc chuột để di chuyển con trỏ soạn thảo.
* Thay đổi độ rộng cột hay độ cao hàng của bảng:
-B1. Đưa con trỏ chuột vào đường biên của cột (hay hàng) cần thay đổi cho đến khi con trỏ có dạng
hoặc
-B2. Kéo chuột sang trái, phải (hoặc lên, xuống) để thay đổi kích thước của hàng hoặc cột.
Hoạt động 3: 3. Định dạng bảng: (Dự kiến thời lượng 5')
a) Mục tiêu: - Học sinh biết cách định dạng bảng.
b) Nội dung: Tìm hiểu về “Định dạng bảng.”. GV yêu cầu học sinh nghiên cứu SGK hoặc quan sát, theo dõi
bài giảng, thảo luận và hoàn thiện phiếu học tập số 8.
c) Sản phẩm: Phiếu học tập của học sinh
Sản phẩm dự kiến:
PHIẾU SỐ 8 CD5B12

Em hãy nêu các - B1. Đặt con trỏ soạn thảo trong bảng
bước để định dạng - B2.Chọn các lệnh định dạng trong thẻ Layout của dải lệnh Table Tools.
bảng?
d) Tổ chức thực hiện:
-Bước 1: Chuyển giao nhiệm vụ
+Hoạt động nhóm (chia từ 2hs/nhóm) hoặc cá nhân. Phát phiếu học tập cho học sinh và yêu cầu học sinh
hoàn thiện phiếu học tập, bài tập
+HS điền thông tin tìm hiểu, nghiên cứu, trả lời các yêu cầu trong phiếu học tập số 8.
+GV: Yêu cầu các nhóm hoàn thành nhiệm vụ học tập.
-Bước 2: Thực hiện nhiệm vụ
+ HS tiếp nhận nhiệm vụ, lắng nghe, nghiên cứu, suy nghĩ và thảo luận, ghi vào vở, phiếu học tập
+ GV quan sát, hướng dẫn HS khi cần
- Bước 3: Báo cáo, thảo luận

4

+ HS trình bày kết quả
+ HS khác nhận xét, bổ sung đáp án cho bạn.
+ HS cùng GV thảo luận nội dung.
- Bước 4: Kết luận, nhận định, đánh giá
+ GV nhận xét, đánh giá và chuẩn kiến thức
+HS: Nhận kết quả đánh giá của giáo viên và so sánh với phương án mẫu, tự sửa sai nếu có. Rút kinh
nghiệm, bài học.
Kiến thức:
* Các bước để định dạng bảng:
- B1. Đặt con trỏ soạn thảo trong bảng
- B2.Chọn các lệnh định dạng trong thẻ Layout của dải lệnh Table Tools.
Hoạt động 4: Thực hành: Tạo bảng: (Dự kiến thời lượng 25')
a) Mục tiêu: Vận dụng, phát huy các kiến thức đã biết, đã hiểu, giải quyết các yêu cầu thực tế.
b) Nội dung: Tìm hiểu về “Tạo bảng” và Thực hành: Tạo bảng. GV yêu cầu học sinh nghiên cứu SGK hoặc
quan sát, theo dõi bài giảng, thảo luận và hoàn thành phiếu số 9, 10, 11, 12.
c) Sản phẩm: Tệp chương trình Word lưu trên máy tính.
d) Tổ chức thực hiện:
-Bước 1: Chuyển giao nhiệm vụ
+Hoạt động nhóm (chia từ 2hs/nhóm) hoặc cá nhân. Phát phiếu học tập cho học sinh và yêu cầu học sinh
hoàn thiện phiếu học tập, bài tập.
+HS tìm hiểu, nghiên cứu các yêu cầu trong phiếu học tập số 9, 10, 11, 12.
+GV: Yêu cầu các nhóm hoàn thành nhiệm vụ học tập.
-Bước 2: Thực hiện nhiệm vụ
+ HS tiếp nhận nhiệm vụ, lắng nghe, nghiên cứu, suy nghĩ và thảo luận, thực hành phiếu số 9, 10, 11, 12.
+ GV quan sát, hướng dẫn HS khi cần
- Bước 3: Báo cáo, thảo luận
+ HS trình bày kết quả
+ HS khác nhận xét, bổ sung đáp án cho bạn.
+ HS cùng GV thảo luận nội dung.
- Bước 4: Kết luận, nhận định, đánh giá
+ GV nhận xét, đánh giá và chuẩn kiến thức
+HS: Nhận kết quả đánh giá của giáo viên và so sánh với phương án mẫu, tự sửa sai nếu có. Rút kinh
nghiệm, bài học.
Kiến thức:
* Thực hành tạo bảng, nhập dữ liệu, định dạng,…
C. HOẠT ĐỘNG LUYỆN TẬP (Dự kiến thời lượng 15')
a) Mục tiêu: Học sinh sử dụng các kiến thức đã học trả lời câu hỏi, giải quyết các vấn đề của bài tập.
Củng cố kiến thức, phát huy trí tuệ.
b) Nội dung: -Hs làm bài tập luyện tập, các phiếu số 13, 14, 15, 16, 17.
c) Sản phẩm: Phiếu học tập của học sinh.
Sản phẩm dự kiến:
PHIẾU SỐ 13 CD5B12. Trắc nghiệm: Chọn đáp án thích hợp:
Trả lời:
Câu 1. Cho các bước tạo bảng:
D
a. Chọn nút tam giác nhỏ bên dưới Table.
b. Di chuyển chuột từ góc trên, bên trái cửa sổ Insert Table để chọn số cột, số hàng.
c. Chọn Insert.
Trật tự sắp xếp các bước đúng:
A. a – b – c
B. b – c – a
C. a – c – b
D. c – a – b
Câu 2. Bạn AN đã nhập số hàng, số cột như hình 5.15 để tạo bảng. Bảng được tạo sẽ có:
A

5

A. 4 cột, 35 hàng

B. 35 cột, 35 hàng.

C. 35 cột, 4 hàng.

D. 4 cột, 4 hàng.

Câu 3. Muốn xoá một số hàng trong bảng, sau khi chọn các hàng cần xoá, em thực hiện lệnh nào sau
đây?

A. Delete Cells.
B. Delete Columns.
C. Delete Rows.
D. Delete Table.
Câu 4. Nhu cầu xử lí thông tin dạng bảng là
A. Dễ so sánh
B. Dễ in ra giấy
C. Dễ học hỏi
D. Dễ di chuyển
Câu 5. Để căn chỉnh lề, hướng của văn bản trong ô bạn cần sử dụng nhóm lệnh:
A. Cell size
B. Alignment
C. Rows & colunms
D. Merge
Câu 6. Trình bày thông tin ở dạng bảng giúp em
A. Biết được nguồn gốc thông tin để có thể dễ dàng tìm kiếm và tổng hợp thông tin.
B. Tạo và định dạng văn bản.
C. Có thể tìm kiếm và sao chép mọi thông tin.

D. Trình bày thông tin một cách cô đọng, có thể dễ dàng tìm kiếm, so sánh, tổng hợp được thông tin.

C
A
B
D

Câu 7. Trong phần mềm soạn thảo, thực hiện các thao tác như hình bên dưới để:

C

A. Chèn thêm một cột vào bên trái.
B. Chèn thêm hàng vào bên phải.
C. Chèn thêm cột vào bên phải
D. Chèn thêm hàng vào bên trái
Câu 8. Bạn Lan đã nhập số hàng và số cột như hình bên dưới để tách một ô thành nhiều ô:

D

A. 2 cột, 2 hàng
B. 1 cột, 2 hàng
C. 1 cột, 1 hàng
D. 2 cột, 1 hàng
Câu 9. Trong nhóm lệnh Alignment của thẻ ngữ cảnh Table Tools/Layout, dữ liệu trong ô được
căn chỉnh theo hai chiều dọc và ngang. Bạn An đã căn chỉnh dữ liệu trong ô để được kết quả

B

như Hình. Bạn đã sử dụng lệnh nào trong nhóm lệnh Alignment:
A. Trên, Trái.
B. Trên, Giữa.
C. Trên, Phải.
D. Giữa, Giữa.
Câu 10. Bảng danh sách lớp 6A với cột Tên được trình bày theo thứ tự vần A, B, C. Để bổ sung
bạn Ngô Văn Chinh vào danh sách mà vẫn đảm bảo yêu cầu danh sách được xếp theo vần A, B,
C của tên, em sẽ thêm một dòng ở vị trí nào của bảng?

C

A. Thêm một dòng vào cuối bảng.
B. Thêm một dòng vào trước dòng chứa tên bạn Bình.
C. Thêm một dòng vào trước dòng chứa tên bạn Dương.
D. Thêm một dòng vào sau dòng chứa tên bạn Dương
Câu 11. Trong bảng danh sách lớp 6A, con trỏ soạn thảo đang được đặt trong ô chứa tên bạn
Bình. Để thêm một dòng vào sau dòng này, em nháy nút phải chuột chọn Insert và chọn tiếp
lệnh nào?

6

B

A. Insert Rows Above.
B. Insert Rows Below.
C. Insert Columns to the Left.
D. Insert Columns to the Right.
Câu 12. Cách di chuyển con trỏ soạn thảo trong bảng là:
A. Chỉ sử dụng các phím mũi tên trên bàn phím.
B. Chỉ sử dụng chuột.
C. Sử dụng thanh cuộn ngang, dọc.
D. Có thể sử dụng chuột, phím Tab hoặc các phím mũi tên trên bàn phím.
Câu 13. Sử dụng lệnh Insert/Table rồi dùng chuột kéo thả để chọn số cột và số hàng thì số cột,
số hàng tối đa có thể tạo được là:
A. 10 cột, 10 hàng.
B. 10 cột, 8 hàng. C. 8 cột, 8 hàng.
D. 8 cột, 10 hàng.
Câu 14. Độ rộng của cột và hàng sau khi được tạo:
A. Luôn luôn bằng nhau
B. Không thể thay đổi
C. Có thể thay đổi
D. Có thể bằng nhau nhưng không thể thay đổi
Câu 15. Nếu muốn tạo bảng nhiều cột, hàng hơn ta thực hiện như thế nào?
A. Insert -> Table -> Quick Tables
B. Insert -> Table -> Insert Table
C. Insert -> Table -> Drawtable
D. Insert -> Table -> Excel Speadsheet
Câu 16. Phát biểu nào trong các phát biểu sau là sai?
A. Bảng giúp trình bày thông tin một cách cô đọng
B. Bảng giúp tìm kiếm, so sánh và tổng hợp thông tin một cách dễ dàng hơn
C. Bảng chỉ có thể biểu diễn dữ liệu là những con số
D. Bảng có thể được dùng để ghi lại dữ liệu của công việc thống kê, điều tra, khảo sát, …
Câu 17. Ý nào sau đây chưa đúng:
A. Delete Columns: Xoá cột đã chọn
B. Delete Rows: Xoá hàng đã chọn
C. Split Cells: Thêm ô
D. Merge Cells: Gộp nhiều ô thành một ô
Câu 18. Muốn xóa bảng, sau khi chọn cả bảng, em nháy chuột phải vào ô bất kì trong bảng rồi
chọn lệnh:
A. Delete Rows
B. Delete Table
C. Delete Columns
D. Delete Cells
Câu 19. Để chèn một bảng có 30 hàng và 10 cột, em sử dụng thao tác nào?
A. Chọn lệnh Insert/Table, kéo thả chuột chọn 30 hàng, 10 cột.
B. Chọn lệnh Insert/Table/Table Tools, nhập 30 hàng, 10 cột.
C. Chọn lệnh Insert/Table/lnsert Table, nhập 30 hàng, 10 cột.
D. Chọn lệnh Table Tools/Layout, nhập 30 hàng, 10 cột.
Câu 20. Nút lệnh dưới đây có chức năng:

A. Chèn thêm hàng, cột
C. Căn chỉnh lề, hướng của văn bản trong ô.

B. Điều chỉnh kích thước dòng, cột.
D. Gộp tách ô, tách bảng

Câu 21. Để chuẩn bị lên kế hoạch cho buổi dã ngoại của lớp, cô giáo giao cho hai bạn Minh và An thu
thập thông tin cho buổi dã ngoại. Theo em, những thông tin nào không nên trình bày dưới dạng bảng?

A. Một đoạn văn mô tả ngắn gọn về địa điểm dã ngoại.
C. Các đồ dùng cần mang theo.
Câu 22. Em có thể sử dụng nút lệnh nào để tạo bảng?

B. Chương trình hoạt động.
D. Phân công chuẩn bị.

A.
B.
C.
D.
Câu 23. Để thay đổi độ rộng của cột, hay chiều cao của hàng em kéo thả chuột khi con trỏ chuột
có hình nào dưới đây.
A.
B.
C.
Câu 24. Em có thể tạo bảng gồm bao nhiêu cột và bao nhiêu hàng?

7

D.

D

B
C
B
C

C
B
C

A

A

B
D

C

A. 5 cột và 4 hàng
B. 4 cột và 5 hàng
C. Bảng có thể có số cột, số hàng rất lớn tùy vào phần mềm Word
D. Tất cả đều sai
Câu 25. Những thao tác nào dưới đây có thể thực hiện với các hàng và các cột của bảng?
A. Thêm một hay nhiều hàng vào bảng
B. Xóa một hay nhiều hàng khỏi bảng
C. Thêm một hay nhiều cột vào bảng
D. Xóa một hay nhiều cột khỏi bảng
Câu 26. Để chèn thêm một hàng vào bảng, em có thể thực hiện thao tác nào dưới đây?
A. Đặt con trỏ soạn thảo vào trong một ô và nhấn phím Enter
B. Đặt con trỏ soạn thảo sang bên phải bảng (ngoài cột cuối cùng ) và nhấn Enter
C. Đặt con trỏ soạn thảo vào trong một ô và nhấn phím Tab
D. Đặt con trỏ soạn thảo vào ô cuối cùng của bảng và nhấn phím Tab.
Câu 27. Khi đặt con trỏ soạn thảo vào trong bảng, chọn lệnh Table Tools -> Layout, cột mới sẽ
được chèn vào bảng ở vị trí nào nếu chọn lệnh Insert Left?
A. Bên trái cột có ô chứa con trỏ soạn thảo.
B. Bên phải cột có ô chứa con trỏ soạn thảo
C. Bên trái bảng.
D. Bên phải bảng

ABCD
BD

A

PHIẾU SỐ 14 CD5B12
Cho hình vẽ minh họa sau: Em hãy cho biết bảng được tạo ra gồm bao nhiêu Bảng gồm 2 hàng 3 cột
hàng, bao nhiêu cột?

PHIẾU SỐ 15 CD5B12
Cho hình vẽ minh họa sau: Em hãy cho biết bảng được tạo ra gồm bao nhiêu Bảng gồm 4 hàng 6 cột
hàng, bao nhiêu cột?

PHIẾU SỐ 16 CD5B12. Nối cột A với cột B để có kết quả đúng:
A.Lệnh

B.CHỨC NĂNG

A+B

1.Delete Rows

a. Xóa toàn bộ bảng

1+ C

2.DELETE COLUMNS

b. Xóa cột có con trỏ soạn thảo

2+ B

3.DELETE TABLE

c. Xóa hàng có con trỏ soạn thảo

3+ A

4.Split Cells

d. Gộp nhiều ô thành nhiều ô

4+ E

5.Merge Cells

e. Tách một ô thành nhiều ô

5+ D

PHIẾU SỐ 17 CD5B12. Nối cột A với cột B để có kết quả đúng:
A.Lệnh

B.CHỨC NĂNG

A+B

1. Insert Left

a. Chèn thêm hàng vào phía trên hàng đã chọn.

1+ C

2. Insert Right

b. Chèn thêm hàng vào phía dưới hàng đã chọn.

2+ D

3. Insert Above

c. Chèn thêm cột vào phía bên trái cột đã chọn.

3+ A

4. Insert Below

d. Chèn thêm cột vào phía bên phải cột đã chọn.

4+ B

8

d) Tổ chức thực hiện:
-Bước 1: Chuyển giao nhiệm vụ
+Hoạt động nhóm (chia từ 2hs/nhóm) hoặc cá nhân. Phát phiếu học tập cho học sinh và yêu cầu học sinh
hoàn thiện phiếu bài tập
+HS điền thông tin tìm hiểu, nghiên cứu, trả lời các yêu cầu trong phiếu số 13, 14, 15, 16, 17.
+GV: Yêu cầu các nhóm hoàn thành nhiệm vụ học tập.
-Bước 2: Thực hiện nhiệm vụ
+ HS tiếp nhận nhiệm vụ, lắng nghe, nghiên cứu, suy nghĩ và thảo luận, hoàn thành phiếu bài tập.
+ GV quan sát, hướng dẫn HS khi cần.
- Bước 3: Báo cáo, thảo luận
+ HS trình bày kết quả.
+ HS khác nhận xét, bổ sung đáp án cho bạn.
+ HS cùng GV thảo luận nội dung.
- Bước 4: Kết luận, nhận định, đánh giá
+ GV nhận xét, đánh giá và chuẩn kiến thức
+HS: Nhận kết quả đánh giá của giáo viên và so sánh với phương án mẫu, tự sửa sai nếu có. Rút kinh
nghiệm, bài học.
D.HOẠT ĐỘNG VẬN DỤNG, MỞ RỘNG (Dự kiến thời lượng 15')
a) Mục tiêu: -HS vận dụng được kiến thức để giải quyết bài tập phần vận dụng
b) Nội dung: GV yêu cầu học sinh nghiên cứu SGK hoặc quan sát, theo dõi bài giảng và hoàn thiện phiếu
bài tập. HS làm bài tập vận dụng và thực hành phiếu 18, 19, 20.
c) Sản phẩm: Bài làm của học sinh. Tệp chương trình lưu trên máy tính.
Sản phẩm dự kiến:
- Kết quả thực hành của HS.
d) Tổ chức thực hiện:
-Bước 1: Chuyển giao nhiệm vụ
+Hoạt động nhóm (chia từ 2hs/nhóm) hoặc cá nhân. Phát phiếu học tập cho học sinh và yêu cầu học sinh
hoàn thiện phiếu bài tập.
+HS tìm hiểu, nghiên cứu, thực hành phiếu số 18, 19, 20.
+GV: Yêu cầu các nhóm hoàn thành nhiệm vụ học tập.
-Bước 2: Thực hiện nhiệm vụ
+ HS tiếp nhận nhiệm vụ, lắng nghe, nghiên cứu, suy nghĩ và thảo luận, hoàn thành phiếu bài tập, bài thực
hành.
+ GV quan sát, hướng dẫn HS khi cần.
- Bước 3: Báo cáo, thảo luận
+ HS trình bày kết quả
+ HS khác nhận xét, bổ sung đáp án cho bạn.
+ HS cùng GV thảo luận nội dung.
- Bước 4: Kết luận, nhận định, đánh giá
+ GV nhận xét, đánh giá và chuẩn kiến thức
+HS: Nhận kết quả đánh giá của giáo viên và so sánh với phương án mẫu, tự sửa sai nếu có. Rút kinh
nghiệm, bài học.
*Lưu ý:
-GV có thể cho học sinh chuẩn bị hoàn thành trước ở phiếu học trước hoặc sau tiết học và báo cáo kết quả
vào thời điểm thích hợp.
-GV tổ chức chia sẻ và đánh giá kết quả làm bài của HS ở thời điểm phù hợp của những tiết học tiếp theo.
IV. Phụ lục: (nếu có)
PHIẾU SỐ 1 CD5B12
Họ và tên: ………………………………….. Lớp:….. Nhóm: ……………………
Hình 5.11 cho thấy hai cách trình -Cách trình bày bảng giúp người xem dễ quan sát và bao quát
bày danh sách học sinh trong cuốn những thông tin trong cuốn sổ lưu niệm hơn nhưng sẽ ghi được ít
sổ lưu niệm. Trang bên trái sử dụng thông tin của từng cá nhân hơn.
bảng, trang bên phải liệt kê lần lượt -Cách trình bày theo danh sách liệt kê giúp người xem dễ dàng nắm
danh sách các thành viên. Em hãy bắt thông tin của từng cá nhân, nhưng không bao quát được tất cả.
nhận xét về hai cách trình bày này?

9

Em sẽ lựa chọn cách nào để trình Mỗi cách trình bày đều có những ưu - nhược điểm của nó
bày danh sách học sinh trong cuốn
sổ lưu niệm của lớp em? Tại sao?
PHIẾU SỐ 2 CD5B12

Bảng trên gồm mấy cột, mấy hàng?
Trò chơi nào được nhiều bạn nam yêu thích nhất?
Trò chơi nào được nhiều bạn nữ yêu thích nhất?

Bảng trên gồm 4 cột , 5 hàng.
Trò chơi kéo co được nhiều bạn nam yêu thích nhất.
Trò chơi lò cò tiếp sức được nhiều bạn nữ yêu thích
nhất.
Trò chơi nào được học sinh của lớp yêu thích Trò chơi kéo co được học sinh của lớp yêu thích
nhất?
nhất.
Nếu không dùng bảng biểu diễn thì việc tìm kiếm Nếu không dùng bảng biểu diễn thì việc tìm kiếm
có dễ không?
khó khăn hơn
PHIẾU SỐ 3 CD5B12
Em hãy nêu tác Tác dụng của việc trình bày thông tin dạng bảng:
dụng của việc -Chúng ta có thể sử dụng bảng để trình bày thông tin một cách cô đọng.
trình bày thông -Bảng thường được sử dụng để ghi lại dữ liệu của công việc thống kê, điều tra, khảo
tin dạng bảng?
sát,...
-Từ bảng dữ liệu, em có thể dễ dàng tìm kiếm, so sánh, tổng hợp được thông tin.
PHIẾU SỐ 4 CD5B12
Em hãy nêu các Cách thực hiện:
bước để tạo bảng? -B1: Chọn lệnh Table trên dải lệnh Insert.
-B2: Kéo thả chuột để chọn số hàng, số cột cho bảng. Một bảng trống được tạo với số
hàng và số cột như đã chọn.
PHIẾU SỐ 5 CD5B12
Tạo bảng bằng hộp thoại Insert Table:
Em hãy nêu các bước
-B1: Chọn Insert/ Table /Insert Table
để tạo bảng bằng hộp
-B2: Nhập số cột, số hàng của bảng.
thoại Insert Table?
-B3: Chọn lệnh OK (Enter)
PHIẾU SỐ 6 CD5B12
Em hãy nêu cách -Muốn nhập nội dung vào ô nào, ta nháy chuột để đặt con trỏ soạn thảo tại ô đó và
nhập nội dung và di nhập dữ liệu.
chuyển trong bảng? -Sử dụng các phím mũi tên trên bàn phím hoặc chuột để di chuyển con trỏ soạn
thảo.
PHIẾU SỐ 7 CD5B12
Em hãy nêu cách Thay đổi độ rộng cột hay độ cao hàng của bảng:
thay đổi độ rộng -B1. Đưa con trỏ chuột vào đường biên của cột (hay hàng) cần thay đổi cho đến khi
cột, độ cao hàng con trỏ có dạng
hoặc
của bảng?
-B2. Kéo chuột sang trái, phải (hoặc lên, xuống) để thay đổi kích thước của hàng
hoặc cột.

PHIẾU SỐ 8 CD5B12

10

Em hãy nêu các - B1. Đặt con trỏ soạn thảo trong bảng
bước để định dạng -B2.Chọn các lệnh định dạng trong thẻ Layout của dải lệnh Table Tools.
bảng?
PHIẾU SỐ 9 CD5B12. Thực hành: Tạo bảng.
Nhiệm vụ: Em hãy tạo bảng tương tự như sau:

PHIẾU SỐ 10 CD5B12. Thực hành: Tạo bảng.
Nhiệm vụ: Em hãy tạo bảng tương tự như sau:

PHIẾU SỐ 11 CD5B12. Thực hành: Tạo bảng.
Nhiệm vụ: Em hãy tạo bảng tương tự như sau:

11

PHIẾU SỐ 12 CD5B12. Thực hành: Tạo bảng.
Nhiệm vụ: Em hãy tạo bảng tương tự như sau:

PHIẾU SỐ 13 CD5B12. Trắc nghiệm: Chọn đáp án thích hợp:
Câu 1. Cho các bước tạo bảng:
a. Chọn nút tam giác nhỏ bên dưới Table.
b. Di chuyển chuột từ góc trên, bên trái cửa sổ Insert Table để chọn số cột, số hàng.
c. Chọn Insert.
Trật tự sắp xếp các bước đúng:
A. a – b – c
B. b – c – a
C. a – c – b
D. c – a – b
Câu 2. Bạn AN đã nhập số hàng, số cột như hình 5.15 để tạo bảng. Bảng được tạo sẽ có:

A. 4 cột, 35 hàng

B. 35 cột, 35 hàng.

C. 35 cột, 4 hàng.

D. 4 cột, 4 hàng.

Câu 3. Muốn xoá một số hàng trong bảng, sau khi chọn các hàng cần xoá, em thực hiện lệnh nào sau
đây?

A. Delete Cells.
B. Delete Columns.
C. Delete Rows.
D. Delete Table.
Câu 4. Nhu cầu xử lí thông tin dạng bảng là
A. Dễ so sánh
B. Dễ in ra giấy
C. Dễ học hỏi
D. Dễ di chuyển
Câu 5. Để căn chỉnh lề, hướng của văn bản trong ô bạn cần sử dụng nhóm lệnh:
A. Cell size
B. Alignment
C. Rows & colunms
D. Merge
Câu 6. Trình bày thông tin ở dạng bảng giúp em
A. Biết được nguồn gốc thông tin để có thể dễ dàng tìm kiếm và tổng hợp thông tin.
B. Tạo và định dạng văn bản.
C. Có thể tìm kiếm và sao chép mọi thông tin.

D. Trình bày thông tin một cách cô đọng, có thể dễ dàng tìm kiếm, so sánh, tổng hợp được thông tin.

Câu 7. Trong phần mềm soạn thảo, thực hiện các thao tác như hình bên dưới để:

12

Trả lời:
D

A

C
A
B
D

C

A. Chèn thêm một cột vào bên trái.
B. Chèn thêm hàng vào bên phải.
C. Chèn thêm cột vào bên phải
D. Chèn thêm hàng vào bên trái
Câu 8. Bạn Lan đã nhập số hàng và số cột như hình bên dưới để tách một ô thành nhiều ô:

D

A. 2 cột, 2 hàng
B. 1 cột, 2 hàng
C. 1 cột, 1 hàng
D. 2 cột, 1 hàng
Câu 9. Trong nhóm lệnh Alignment của thẻ ngữ cảnh Table Tools/Layout, dữ liệu trong ô được
căn chỉnh theo hai chiều dọc và ngang. Bạn An đã căn chỉnh dữ liệu trong ô để được kết quả

B

như Hình. Bạn đã sử dụng lệnh nào trong nhóm lệnh Alignment:
A. Trên, Trái.
B. Trên, Giữa.
C. Trên, Phải.
D. Giữa, Giữa.
Câu 10. Bảng danh sách lớp 6A với cột Tên được trình bày theo thứ tự vần A, B, C. Để bổ sung
bạn Ngô Văn Chinh vào danh sách mà vẫn đảm bảo yêu cầu danh sách được xếp theo vần A, B,
C của tên, em sẽ thêm một dòng ở vị trí nào của bảng?

C

A. Thêm một dòng vào cuối bảng.
B. Thêm một dòng vào trước dòng chứa tên bạn Bình.
C. Thêm một dòng vào trước dòng chứa tên bạn Dương.
D. Thêm một dòng vào sau dòng chứa tên bạn Dương
Câu 11. Trong bảng danh sách lớp 6A, con trỏ soạn thảo đang được đặt trong ô chứa tên bạn
Bình. Để thêm một dòng vào sau dòng này, em nháy nút phải chuột chọn Insert và chọn tiếp
lệnh nào?

A. Insert Rows Above.
B. Insert Rows Below.
C. Insert Columns to the Left.
D. Insert Columns to the Right.
Câu 12. Cách di chuyển con trỏ soạn thảo trong bảng là:
A. Chỉ sử dụng các phím mũi tên trên bàn phím.
B. Chỉ sử dụng chuột.
C. Sử dụng thanh cuộn ngang, dọc.
D. Có thể sử dụng chuột, phím Tab hoặc các phím mũi tên trên bàn phím.
Câu 13. Sử dụng lệnh Insert/Table rồi dùng chuột kéo thả để chọn số cột và số hàng thì số cột,
số hàng tối đa có thể tạo được là:
A. 10 cột, 10 hàng.
B. 10 cột, 8 hàng. C. 8 cột, 8 hàng.
D. 8 cột, 10 hàng.
Câu 14. Độ rộng của cột và hàng sau khi được tạo:
A. Luôn luôn bằng nhau
B. Không thể thay đổi
C. Có thể thay đổi
D. Có thể bằng nhau nhưng không thể thay đổi
Câu 15. Nếu muốn tạo bảng nhiều cột, hàng hơn ta thực hiện như thế nào?
A. Insert -> Table -> Quick Tables
B. Insert -> Table -> Insert Table
C. Insert -> Table -> Drawtable
D. Insert -> Table -> Excel Speadsheet
Câu 16. Phát biểu nào trong các phát biểu sau là sai?
A. Bảng giúp trình bày thông tin một cách cô đọng
B. Bảng giúp tìm kiếm, so sánh và tổng hợp thông tin một cách dễ dàng hơn
C. Bảng chỉ có thể biểu diễn dữ liệu là những con số
D. Bảng có thể được dùng để ghi lại dữ liệu của công việc thống kê, điều tra, khảo sát, …
Câu 17. Ý nào sau đây chưa đúng:

13

B

D

B
C
B
C

C

A. Delete Columns: Xoá cột đã chọn
C. Split Cells: Thêm ô

B. Delete Rows: Xoá hàng đã chọn
D. Merge Cells: Gộp nhiều ô thành một ô

Câu 18. Muốn xóa bảng, sau khi chọn cả bảng, em nháy chuột phải vào ô bất kì trong bảng rồi chọn lệnh:

A. Delete Rows
B. Delete Table
C. Delete Columns
D. Delete Cells
Câu 19. Để chèn một bảng có 30 hàng và 10 cột, em sử dụng thao tác nào?
A. Chọn lệnh Insert/Table, kéo thả chuột chọn 30 hàng, 10 cột.
B. Chọn lệnh Insert/Table/Table Tools, nhập 30 hàng, 10 cột.
C. Chọn lệnh Insert/Table/lnsert Table, nhập 30 hàng, 10 cột.
D. Chọn lệnh Table Tools/Layout, nhập 30 hàng, 10 cột.
Câu 20. Nút lệnh dưới đây có chức năng:

A. Chèn thêm hàng, cột
C. Căn chỉnh lề, hướng của văn bản trong ô.

B. Điều chỉnh kích thước dòng, cột.
D. Gộp tách ô, tách bảng

Câu 21. Để chuẩn bị lên kế hoạch cho buổi dã ngoại của lớp, cô giáo giao cho hai bạn Minh và An thu
thập thông tin cho buổi dã ngoại. Theo em, những thông tin nào không nên trình bày dưới dạng bảng?

A. Một đoạn văn mô tả ngắn gọn về địa điểm dã ngoại.
C. Các đồ dùng cần mang theo.
Câu 22. Em có thể sử dụng nút lệnh nào để tạo bảng?

B. Chương trình hoạt động.
D. Phân công chuẩn bị.

A.
B.
C.
D.
Câu 23. Để thay đổi độ rộng của cột, hay chiều cao của hàng em kéo thả chuột khi con trỏ chuột
có hình nào dưới đây.
A.
B.
C.
D.
Câu 24. Em có thể tạo bảng gồm bao nhiêu cột và bao nhiêu hàng?
A. 5 cột và 4 hàng
B. 4 cột và 5 hàng
C. Bảng có thể có số cột, số hàng rất lớn tùy vào phần mềm Word
D. Tất cả đều sai
Câu 25. Những thao tác nào dưới đây có thể thực hiện với các hàng và các cột của bảng?
A. Thêm một hay nhiều hàng vào bảng
B. Xóa một hay nhiều hàng khỏi bảng
C. Thêm một hay nhiều cột vào bảng
D. Xóa một hay nhiều cột khỏi bảng
Câu 26. Để chèn thêm một hàng vào bảng, em có thể thực hiện thao tác nào dưới đây?...
 
Gửi ý kiến

↓ CHÚ Ý: Bài giảng này được nén lại dưới dạng 7Z và có thể chứa nhiều file. Hệ thống chỉ hiển thị 1 file trong số đó, đề nghị các thầy cô KIỂM TRA KỸ TRƯỚC KHI NHẬN XÉT  ↓